# ./addons/eventscripts/popuptest/popuptest.py

import cmdlib
import es
import gamethread


from cheappopup import *

popup = CheapPopup()

###

def normalPopup(userid, args=None):
   es.msg('Begin CheapPopup test')
   popup.sendMenu(userid, 0, 'Press any number key (0-9)\nto continue', normalPopupSelect)

cmdlib.registerSayCommand('!popuptest', normalPopup, 'CheapPopup test')

def normalPopupSelect(userid, item):
   es.msg('Normal selection: ' + str(item))
   tuplePopup(userid)

###

DATA = (
 'Apples',
 'Oranges',
 'Bananas',
 'Grapes',
 'Pineapple',
 'Star fruit',
 'Tangerines',
 'Watermelon',
 'Cucumber',
 )

def tuplePopup(userid):
   # With a tuple, list, or any other ordered (has the __getslice__ attribute) data type
   # the selections are displayed in the order they appear
   popup.sendSelectionMenu(userid, DATA, tuplePopupSelect, nohighlight=('Star fruit',))

def tuplePopupSelect(userid, item):
   # With a tuple, list, or any other ordered (has the __getslice__ attribute) data type
   # the return item is the selection number
   es.msg('Tuple selection: ' + str(item))
   setPopup(userid)

###

def setPopup(userid):
   # With a set or frozenset data type the selections are displayed in sorted(...) order
   popup.sendSelectionMenu(userid, set(DATA), setPopupSelect)
   # Because the "order" attribute takes precedence, we can define the order attribute
   # to specify an order for this set:
   # s = SelectionSet(DATA)
   # s.order = sorted(s, reverse=True)

def setPopupSelect(userid, item):
   # With a set or frozenset data type the item returned is the selection displayed
   es.msg('Set selection: ' + str(item))
   dictPopup(userid)

###

def dictPopup(userid):
   # With a dictionary of items the selections are displayed in sorted(...) order
   d = dict((es.getplayername(x), x) for x in es.getUseridList())
   popup.sendSelectionMenu(userid, d, dictPopupSelect, 'Select a player')

def dictPopupSelect(userid, item):
   # With a dictionary the returned item is the value corresponding to the
   # dictionary key selected
   es.msg('Dict selection (userid): ' + str(item))
   orderedDictPopup(userid)

###

# SelectionDict can be used to specifiy a dictionary of selections in a specific order
SDATA = SelectionDict()
SDATA['Apples'] = 'Malus domestica'
SDATA['Star fruit'] = 'Damasonium alisma'
SDATA['Oranges'] = 'Citrus sinensis'

def orderedDictPopup(userid):
   # With a SelectionDict of items the items are displayed in the order they were added
   # to the dictionary
   popup.sendSelectionMenu(userid, SDATA, orderedDictPopupSelect)

def orderedDictPopupSelect(userid, item):
   # With a SelectionDict of items the returned item is the dictionary value of the
   # selected key
   es.msg('SelectionDict selection: ' + str(item))
   finalPopup(userid)

###

def finalPopup(userid):
   # Send this popup and then test the close method in five seconds
   popup.sendMenu(userid, 0, 'Goodbye!')
   gamethread.delayed(5, popup.closeMenu, userid)
   # Traditionally this would be done with:
   #popup.sendMenu(userid, 5, 'Goodbye!')
   gamethread.delayed(7, escMenu, userid)

###

def escMenu(userid, args=None):
   es.msg('sending ESC menu')
   popup.sendESCMenu(userid, 10, 'Title goes here', 'Test ESC menu')
   gamethread.delayed(12, buttonESC, userid)

###

def buttonESC(userid):
   es.msg('sending button ESC menu')
   popup.sendESCButtonMenu(userid, 10, 'What a title', 'Button fun!',
    ('Item 1', 'Item 2', 'Button 3', 'B4', 'B5'), buttonESCSelect)

def buttonESCSelect(userid, item):
   # Button selections return the button number (starting with 1)
   es.msg('Button selection: ' + str(item))
   #inputESC(userid)
   tupleESC(userid)

###
'''
def inputESC(userid):
   es.msg('sending input ESC menu')
   popup.sendESCInputMenu(userid, 20, 'String input', 'Gimme a string, foo', inputESCSelection)

def inputESCSelection(userid, input):
   es.msg('String input: ' + str(input))
   tupleESC(userid)'''

###

def tupleESC(userid):
   es.msg('sending button ESC menu')
   # With a tuple, list, or any other ordered (has the __getslice__ attribute) data type
   # the selections are displayed in the order they appear
   popup.sendESCButtonSelectionMenu(userid, 10, DATA, tupleESCSelect)

def tupleESCSelect(userid, item):
   # With a tuple, list, or any other ordered (has the __getslice__ attribute) data type
   # the return item is the selection number
   es.msg('Tuple selection: ' + str(item))
   setESC(userid)

###

def setESC(userid):
   es.msg('sending button ESC menu')
   # With a set or frozenset data type the selections are displayed in sorted(...) order
   popup.sendESCButtonSelectionMenu(userid, 10, set(DATA), setESCSelect)
   # Because the "order" attribute takes precedence, we can define the order attribute
   # to specify an order for this set:
   # s = SelectionSet(DATA)
   # s.order = sorted(s, reverse=True)

def setESCSelect(userid, item):
   # With a set or frozenset data type the item returned is the selection displayed
   es.msg('Set selection: ' + str(item))
   dictESC(userid)

###

def dictESC(userid):
   es.msg('sending button ESC menu')
   # With a dictionary of items the selections are displayed in sorted(...) order
   d = dict((es.getplayername(x), x) for x in es.getUseridList())
   popup.sendESCButtonSelectionMenu(userid, 10, d, dictESCSelect, 'Select a player')

def dictESCSelect(userid, item):
   # With a dictionary the returned item is the value corresponding to the
   # dictionary key selected
   es.msg('Dict selection (userid): ' + str(item))
   orderedDictESC(userid)

###

def orderedDictESC(userid):
   es.msg('sending button ESC menu')
   # With a SelectionDict of items the items are displayed in the order they were added
   # to the dictionary
   popup.sendESCButtonSelectionMenu(userid, 10, SDATA, orderedDictESCSelect)

def orderedDictESCSelect(userid, item):
   # With a SelectionDict of items the returned item is the dictionary value of the
   # selected key
   es.msg('SelectionDict selection: ' + str(item))
   finalESC(userid)

###

def finalESC(userid):
   es.msg('sending ESC menu')
   # Send this popup and then test the close method in five seconds
   popup.sendESCMenu(userid, 20, 'ESC goodbye', 'Goodbye!')
   gamethread.delayed(5, popup.closeESCMenu, userid)

###

def unload():
   cmdlib.unregisterSayCommand('popuptest')
   popup.unload()